@@ -84,27 +84,39 @@ resolver_endpoint <- function(service, region, endpoints, sts_regional_endpoint
     match <- matches[order(nchar(matches), decreasing = TRUE)][1]
     return(match)
   }
-  signing_region <- NULL
-  if (service == "sts" & nzchar(sts_regional_endpoint)) {
-    global <- vapply(endpoints, function(x) x$global, FUN.VALUE = logical(1))
-    endpoint <- endpoints[global][[1]]$endpoint
-    endpoints[global][[1]]$endpoint <- set_sts_regional_endpoint(
-      sts_regional_endpoint,
-      endpoint
-    )
-    signing_region <- set_sts_signing_region(sts_regional_endpoint, region)
+  # Set default region for s3:
+  # https://github.com/boto/botocore/blob/develop/botocore/regions.py#L189-L220
+  if (service == "s3" & (region == "aws-global")) {
+    region <- "us-east-1"
   }
-
-
-  e <- endpoints[[get_region_pattern(region, endpoints)]]
+  # locate global endpoint
+  global_found <- vapply(
+    endpoints, function(x) if (is.list(x)) x$global else FALSE,
+    FUN.VALUE = logical(1)
+  )
+  global_region <- (region == "aws-global")
+  if (!any(global_found) & global_region) {
+    stop("No region provided and no global region found.")
+  }
+  search_region <- (
+    if (any(global_found) & global_region) names(global_found[global_found][1]) else region
+  )
+  e <- endpoints[[get_region_pattern(search_region, endpoints)]]
   # TODO: Delete old endpoint format handling once all packages are updated.
   if (is.character(e)) {
     e <- list(endpoint = e, global = FALSE)
   }
-  endpoint <- gsub("{service}", service, e$endpoint, fixed = TRUE)
-  endpoint <- gsub("{region}", region, endpoint, fixed = TRUE)
+  if (service == "sts" & nzchar(sts_regional_endpoint)) {
+    e$endpoint <- set_sts_regional_endpoint(
+      sts_regional_endpoint, e
+    )
+    region <- set_sts_region(sts_regional_endpoint, region)
+  }
+  signing_region <- if (e[["global"]]) "us-east-1" else region
+  endpoint <- gsub("{service}", service, e[["endpoint"]], fixed = TRUE)
+  endpoint <- gsub("{region}", signing_region, endpoint, fixed = TRUE)
   endpoint <- gsub("^(.+://)?", sprintf("%s://", scheme), endpoint)
-  signing_region <- signing_region %||% ifelse(e$global, "us-east-1", region)
+
   return(list(
     endpoint = endpoint,
     signing_region = signing_region
@@ -119,7 +131,7 @@ set_sts_regional_endpoint <- function(sts_regional_endpoint, endpoint) {
   )
 }
 
-set_sts_signing_region <- function(sts_regional_endpoint, region) {
+set_sts_region <- function(sts_regional_endpoint, region) {
   switch(sts_regional_endpoint,
     "legacy" = "us-east-1",
     "regional" = region
